@@ -10,7 +10,7 @@ use warnings;
 use base qw( Devel::MAT::Tool );
 use utf8;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 use Getopt::Long qw( GetOptionsFromArray );
 use List::Util qw( pairs );
@@ -32,11 +32,6 @@ by how it can be reached from well-known program roots.
 
 =cut
 
-my $YELLOW = "\e[33m";
-my $CYAN   = "\e[36m";
-
-my $NORMAL = "\e[m";
-
 my %STRENGTH_ORDER = (
    strong   => 1,
    weak     => 2,
@@ -50,65 +45,80 @@ my %seen;
 
 sub walk_graph
 {
-   my ( $node ) = @_;
+   my ( $node, $indent ) = @_;
+   $indent //= "";
 
    my @roots = $node->roots;
    my @edges = $node->edges_in;
 
    if( !@roots and !@edges ) {
-      return "└─not found";
+      Devel::MAT::Cmd->printf( "$indent└─not found\n" );
+      return;
    }
 
    if( @roots == 1 and $roots[0] eq "EDEPTH" ) {
-      return "└─not found at this depth";
+      Devel::MAT::Cmd->printf( "$indent└─not found at this depth\n" );
+      return;
    }
 
    if( @edges > 0 and $seen{$node->addr}++ ) {
-      my $id = $id_for{$node->addr};
-      return defined $id ? "└─already found as $YELLOW*$id$NORMAL"
-                         : "└─already found ${YELLOW}circularly$NORMAL";
+      Devel::MAT::Cmd->printf( "$indent└─already found " );
+
+      if( defined( my $id = $id_for{$node->addr} ) ) {
+         Devel::MAT::Cmd->printf( "as " );
+         Devel::MAT::Cmd->print_note( "*$id" );
+      }
+      else {
+         Devel::MAT::Cmd->print_note( "circularly" );
+      }
+      Devel::MAT::Cmd->printf( "\n" );
+      return;
    }
 
-   my @blocks = map { [ $_ ] } @roots;
+   foreach my $idx ( 0 .. $#roots ) {
+      my $isfinal = $idx == $#roots && !@edges;
 
-   foreach ( nsort_by { $STRENGTH_ORDER{$_->[0]->strength} } pairs @edges ) {
-      my ( $ref, $refnode ) = @$_;
+      Devel::MAT::Cmd->printf( $indent . ( $isfinal ? "└─%s\n" : "├─%s\n" ),
+         $roots[$idx]
+      );
+   }
 
-      my $str = "";
-      $str = "$CYAN\[${\$ref->strength}]$NORMAL" if $ref->strength ne "strong";
+   my @refs = nsort_by { $STRENGTH_ORDER{$_->[0]->strength} } pairs @edges;
+   foreach my $idx ( 0 .. $#refs ) {
+      my ( $ref, $refnode ) = @{ $refs[$idx] };
+      my $is_final = $idx == $#refs;
+
+      Devel::MAT::Cmd->printf(
+         $indent . ( $is_final ? "└─" : "├─" ) );
+
+      Devel::MAT::Cmd->print_note(
+         "[" . $ref->strength . "]", 1 ) if $ref->strength ne "strong";
 
       my $ref_id;
       if( $refnode->edges_out > 1 and not $refnode->roots and not $id_for{$refnode->addr} ) {
          $ref_id = $id_for{$refnode->addr} = $next_id++;
       }
 
-      my $header = sprintf "%s%s of %s, which is%s:",
-         $str, $ref->name, $refnode->sv->desc_addr, $ref_id ? " $YELLOW(*$ref_id)$NORMAL" : "";
+      Devel::MAT::Cmd->printf( "%s of ", $ref->name );
+      Devel::MAT::Cmd->print_sv( $refnode->sv );
+      Devel::MAT::Cmd->printf( ", which is" );
+
+      if( $ref_id ) {
+         Devel::MAT::Cmd->printf( " " );
+         Devel::MAT::Cmd->print_note( "(*$ref_id)" );
+      }
+
+      Devel::MAT::Cmd->printf( ":\n" );
+
+      my $subindent = $indent . ( $is_final ? "  " : "│ " );
 
       if( $refnode->addr == $node->addr ) {
-         push @blocks, [ $header, "itself" ];
+         Devel::MAT::Cmd->printf( "${subindent}itself\n" );
       }
       else {
-         push @blocks, [ $header, walk_graph( $refnode ) ];
+         walk_graph( $refnode, $subindent );
       }
    }
-
-   my @ret;
-   foreach my $i ( 0 .. $#blocks ) {
-      my $block = $blocks[$i];
-      my $firstline = shift @$block;
-
-      if( $i < $#blocks ) {
-         push @ret, "├─$firstline",
-              map { "│ $_" } @$block;
-      }
-      else {
-         push @ret, "└─$firstline",
-              map { "  $_" } @$block;
-      }
-   }
-
-   return @ret;
 }
 
 =head1 COMMANDS
@@ -143,12 +153,18 @@ Include both weak and indirect references in the output.
 
 =item --no-elide, -n
 
-Don't elide C<REF()>-type SVs from the output. By default these will be
-skipped over, leading to a shorter neater output by removing this
-usually-unnecessary noise.
+Don't elide structure in the output.
 
-If this option is not given, elided reference SVs will be notated by adding
-C<(via RV)> to the reference description.
+By default, C<REF()>-type SVs will be skipped over, leading to a shorter
+neater output by removing this usually-unnecessary noise. If this option is
+not given, elided reference SVs will be notated by adding C<(via RV)> to the
+reference description.
+
+Additionally, members of the symbol table will be printed as being root SVs,
+noting their symbol table name. This avoids additional nesting due to the
+stashes and globs that make up the symbol table. This can also cause SVs to be
+recognised as symbol table entries, when without it they might be cut off due
+to the depth limit.
 
 =back
 
@@ -174,15 +190,14 @@ sub run_cmd
       'no-elide|n' => sub { $ELIDE = 0; },
    ) or return;
 
-   my $addr = $_[0] // die "Need an SV addr\n";
-   $addr = hex $addr if $addr =~ m/^0x/;
+   my $sv = $self->get_sv( $_[0] );
 
-   my $sv = $self->{df}->sv_at( $addr ) or
-      die sprintf "No such SV at address %x\n", $addr;
+   $self->pmat->load_tool( "Inrefs", progress => $self->{progress} );
 
-   Devel::MAT::Cmd->printf( "%s is:\n", $sv->desc_addr );
+   Devel::MAT::Cmd->print_sv( $sv );
+   Devel::MAT::Cmd->printf( " is:\n" );
 
-   Devel::MAT::Cmd->printf( "%s\n", $_ ) for walk_graph( $self->{pmat}->inref_graph( $sv,
+   walk_graph( $self->pmat->inref_graph( $sv,
       depth => $DEPTH,
       strong => $STRONG,
       direct => $DIRECT,
